%{?scl:%scl_package lucene3}
%{!?scl:%global pkg_name %{name}}

%global baserelease 2

%global majorversion 3

Summary:        High-performance, full-featured text search engine
Name:           %{?scl_prefix}lucene3
Version:        3.6.2
Release:        14.%{baserelease}%{?dist}
Epoch:          0
License:        ASL 2.0 and BSD
URL:            http://lucene.apache.org/
Source0:        https://archive.apache.org/dist/lucene/java/%{version}/lucene-%{version}-src.tgz
Source1:        lucene-%{version}-core-OSGi-MANIFEST.MF
Source2:        lucene-%{version}-analysis-OSGi-MANIFEST.MF
Source3:        ivy-conf.xml
# DictionaryBasedBreakIterator was moved into the base RuleBasedBreakIterator
# in icu4j. v49 => v50
Patch0:         lucene_contrib_icu4j_v50.patch
# Add hamcrest-core in classpath
# Disable doclint in javadoc task
Patch1:         lucene-3.6.2-hamcrest-core.patch
# javascript not allowed in javadoc
Patch2:         lucene-3.6.2-javascript.patch
#svn export http://svn.apache.org/repos/asf/lucene/dev/tags/lucene_solr_3_6_2/dev-tools@r1450168
#tar caf dev-tools.tar.xz dev-tools/
Source4:        dev-tools.tar.xz

BuildRequires:  %{?scl_prefix_maven}javapackages-local
BuildRequires:  %{?scl_prefix_maven}ant
BuildRequires:  %{?scl_prefix_maven}ant-junit
BuildRequires:  %{?scl_prefix_maven}junit
BuildRequires:  %{?scl_prefix_maven}javacc
BuildRequires:  java-javadoc
BuildRequires:  %{?scl_prefix_maven}jtidy
BuildRequires:  %{?scl_prefix_maven}regexp
BuildRequires:  %{?scl_prefix_maven}apache-commons-digester
BuildRequires:  java-devel >= 1:1.6.0
BuildRequires:  %{?scl_prefix_maven}apache-commons-compress
BuildRequires:  %{?scl_prefix_maven}apache-ivy
BuildRequires:  %{?scl_prefix}lucene
BuildRequires:  %{?scl_prefix_maven}apache-commons-codec

# for tests
BuildRequires:  subversion
BuildRequires:  %{?scl_prefix_maven}hamcrest-core

BuildRequires:  %{?scl_prefix}icu4j
BuildRequires:  %{?scl_prefix_maven}xerces-j2

BuildArch:      noarch

%description
Apache Lucene is a high-performance, full-featured text search
engine library written entirely in Java. It is a technology suitable
for nearly any application that requires full-text search, especially
cross-platform.

%package contrib
Summary:        Lucene contributed extensions
Requires:       %{name} = %{epoch}:%{version}-%{release}

%description contrib
%{summary}.

%package javadoc
Summary:        Javadoc for Lucene

%description javadoc
%{summary}.

%prep
%{?scl:scl enable %{scl_maven} %{scl} - << "EOFSCL"}
set -e -x
%setup -q -n lucene-%{version}
# remove all binary libs
find . -name "*.jar" -delete

tar xfs %{SOURCE4}
pushd dev-tools
find . -name "pom.xml.template" -exec sed -i "s/@version@/%{version}/g" '{}' \;
popd

iconv --from=ISO-8859-1 --to=UTF-8 CHANGES.txt > CHANGES.txt.new

# prepare pom files (replace @version@ with real version)
find . -name '*pom.xml.template' -exec \
              sed -i "s:@version@:%{version}:g" '{}' \;

cp %{SOURCE3} .

#modify artifactIds to make it easier to map to fedora
sed -i -e "s|ant-junit|ant/ant-junit|g" test-framework/ivy.xml
sed -i -e "s|xercesImpl|xerces-j2|g" contrib/benchmark/ivy.xml
sed -i -e "s|jakarta-regexp|regexp|g" contrib/queries/ivy.xml
sed -i -e "s|lucene-core|lucene/lucene-core|g" backwards/ivy.xml
sed -i -e "s|icu4j|icu4j/icu4j|g" contrib/icu/ivy.xml

# ICU4J v50 compatibility
%patch0 -p2
%patch1 -p1
%patch2 -p1
%{?scl:EOFSCL}

%build
%{?scl:scl enable %{scl_maven} %{scl} - << "EOFSCL"}
set -e -x
mkdir -p docs
mkdir -p lib
export OPT_JAR_LIST="ant/ant-junit junit hamcrest/core"
export CLASSPATH=$(build-classpath jtidy regexp commons-digester apache-commons-compress ivy)

ant -Divy.settings.file=%{_sysconfdir}/ivy/ivysettings.xml -Dbuild.sysclasspath=first \
  -Djavacc.home=%{_bindir}/javacc \
  -Djavacc.jar=%{_javadir}/javacc.jar \
  -Djavacc.jar.dir=%{_javadir} \
  -Djavadoc.link=file://%{_javadocdir}/java \
  -Dversion=%{version} \
  -Dfailonjavadocwarning=false \
  -Dmaven-tasks.uptodate=true \
  -Djavac.source=1.6 \
  -Djavac.target=1.6 \
  jar-lucene-core docs javadocs-core

export CLASSPATH=$(build-classpath jtidy regexp commons-digester apache-commons-compress icu4j ivy)
ant -Divy.settings.file=%{_sysconfdir}/ivy/ivysettings.xml -Dbuild.sysclasspath=first \
  -Djavacc.home=%{_bindir}/javacc \
  -Djavacc.jar=%{_javadir}/javacc.jar \
  -Djavacc.jar.dir=%{_javadir} \
  -Djavadoc.link=file://%{_javadocdir}/java \
  -Dversion=%{version} \
  -Dfailonjavadocwarning=false \
  -Dmaven-tasks.uptodate=true \
  -Djavac.source=1.6 \
  -Djavac.target=1.6 \
  -Djavac.source.backwards=1.6 \
  -Djavac.target.backwards=1.6 \
  jar-test-framework javadocs build-contrib

# add missing OSGi metadata to manifests
mkdir META-INF
unzip -o build/core/lucene-core-%{version}.jar META-INF/MANIFEST.MF
cp %{SOURCE1} META-INF/MANIFEST.MF
sed -i '/^\r$/d' META-INF/MANIFEST.MF
zip build/core/lucene-core-%{version}.jar META-INF/MANIFEST.MF

unzip -o build/contrib/analyzers/common/lucene-analyzers-%{version}.jar META-INF/MANIFEST.MF
cp %{SOURCE2} META-INF/MANIFEST.MF
sed -i '/^\r$/d' META-INF/MANIFEST.MF
zip build/contrib/analyzers/common/lucene-analyzers-%{version}.jar META-INF/MANIFEST.MF

mv build/contrib/analyzers/common build/contrib/analyzers/analyzers
mv dev-tools/maven/lucene/contrib/analyzers/common dev-tools/maven/lucene/contrib/analyzers/analyzers
%{?scl:EOFSCL}

%install
%{?scl:scl enable %{scl_maven} %{scl} - << "EOFSCL"}
set -e -x

# jars
install -d -m 0755 $RPM_BUILD_ROOT%{_javadir}/%{pkg_name}
install -d -m 0755 $RPM_BUILD_ROOT%{_mavenpomdir}
install -pm 0644 build/core/lucene-core-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{pkg_name}/lucene-core.jar

install -pm 0644 dev-tools/maven/lucene/core/pom.xml.template $RPM_BUILD_ROOT/%{_mavenpomdir}/JPP.%{pkg_name}-lucene-core.pom
%add_maven_depmap JPP.%{pkg_name}-lucene-core.pom %{pkg_name}/lucene-core.jar -v "%{majorversion},%{version}"

install -pm 0644 dev-tools/maven/lucene/pom.xml.template $RPM_BUILD_ROOT/%{_mavenpomdir}/JPP.%{pkg_name}-lucene-parent.pom
%add_maven_depmap JPP.%{pkg_name}-lucene-parent.pom -v "%{majorversion},%{version}"

install -pm 0644 dev-tools/maven/pom.xml.template $RPM_BUILD_ROOT/%{_mavenpomdir}/JPP.%{pkg_name}-solr-grandparent.pom
%add_maven_depmap JPP.%{pkg_name}-solr-grandparent.pom -v "%{majorversion},%{version}"

# contrib jars
install -d -m 0755 $RPM_BUILD_ROOT%{_javadir}/%{pkg_name}-contrib

for c in benchmark demo facet grouping highlighter \
         icu instantiated join memory misc pruning queries queryparser remote \
         spatial spellchecker xml-query-parser; do
    install -pm 0644 build/contrib/$c/lucene-${c}-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{pkg_name}-contrib/lucene-${c}.jar
    install -pm 0644 dev-tools/maven/lucene/contrib/$c/pom.xml.template $RPM_BUILD_ROOT/%{_mavenpomdir}/JPP.%{pkg_name}-contrib-lucene-$c.pom
    %add_maven_depmap JPP.%{pkg_name}-contrib-lucene-$c.pom %{pkg_name}-contrib/lucene-${c}.jar -v "%{majorversion},%{version}" -f contrib
done

# contrib analyzers
for c in analyzers kuromoji phonetic smartcn stempel; do
    install -pm 0644 build/contrib/analyzers/$c/lucene-${c}-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{pkg_name}-contrib/lucene-${c}.jar

    install -pm 0644 dev-tools/maven/lucene/contrib/analyzers/$c/pom.xml.template $RPM_BUILD_ROOT/%{_mavenpomdir}/JPP.%{pkg_name}-contrib-lucene-$c.pom
    %add_maven_depmap JPP.%{pkg_name}-contrib-lucene-$c.pom %{pkg_name}-contrib/lucene-${c}.jar -v "%{majorversion},%{version}" -f contrib
done

# contrib pom
install -pm 0644 dev-tools/maven/lucene/contrib/pom.xml.template $RPM_BUILD_ROOT/%{_mavenpomdir}/JPP.%{pkg_name}-lucene-contrib.pom
%add_maven_depmap JPP.%{pkg_name}-lucene-contrib.pom -v "%{majorversion},%{version}" -f contrib

# javadoc
install -d -m 0755 $RPM_BUILD_ROOT%{_javadocdir}/%{pkg_name}
cp -pr build/docs/api/* $RPM_BUILD_ROOT%{_javadocdir}/%{pkg_name}
%{?scl:EOFSCL}

%files -f .mfiles
%doc CHANGES.txt README.txt
%license LICENSE.txt NOTICE.txt

%files javadoc
%license LICENSE.txt NOTICE.txt
%{_javadocdir}/%{pkg_name}

%files contrib -f .mfiles-contrib
%{_javadir}/%{pkg_name}-contrib
%doc contrib/CHANGES.txt
%license LICENSE.txt NOTICE.txt

%changelog
* Tue Aug 21 2018 Mat Booth <mat.booth@redhat.com> - 0:3.6.2-14.2
- Build contrib jars
- Fix ivy artifact lookup

* Tue Aug 21 2018 Mat Booth <mat.booth@redhat.com> - 0:3.6.2-14.1
- Auto SCL-ise package for rh-eclipse collection

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0:3.6.2-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Thu Feb 08 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0:3.6.2-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Mon Oct 09 2017 Troy Dawson <tdawson@redhat.com> - 0:3.6.2-12
- Fix zip -u in spec file causes race condition (#1495231)
- Cleanup spec file conditionals

* Fri Sep 22 2017 Mat Booth <mat.booth@redhat.com> - 0:3.6.2-11
- Add missing BRs to fix FTBFS

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0:3.6.2-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Wed Feb 08 2017 gil cattaneo <puntogil@libero.it> 0:3.6.2-9
- fix FTBFS

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0:3.6.2-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sat Aug 15 2015 gil cattaneo <puntogil@libero.it> 0:3.6.2-7
- fix FTBFS rhbz#1239659
- fix BR list
- introduce license macro
- fix some rpmlint problem

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:3.6.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri Jun 13 2014 Marek Goldmann <mgoldman@redhat.com> - 0:3.6.2-5
- Support for new xmvn

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:3.6.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed May 28 2014 Mikolaj Izdebski <mizdebsk@redhat.com> - 0:3.6.2-3
- Rebuild to regenerate Maven auto-requires

* Wed Apr 16 2014 Marek Goldmann <mgoldman@redhat.com> - 0:3.6.2-2
- Added other modules
- Fixed timestamps
- Updated license field

* Mon Apr 14 2014 Marek Goldmann <mgoldman@redhat.com> - 0:3.6.2-1
- Repackaged as a compat package
